CompressionError

Enum CompressionError 

pub enum CompressionError {
    BufferOperationFailed {
        operation: &'static str,
        algorithm: Algorithm,
        input_len: usize,
        output_capacity: usize,
    },
    StreamInitFailed {
        operation: &'static str,
        algorithm: Algorithm,
    },
    StreamProcessFailed {
        operation: &'static str,
        algorithm: Algorithm,
        status: i32,
    },
    StreamStalled {
        operation: &'static str,
        algorithm: Algorithm,
    },
    StreamFinished {
        operation: &'static str,
        algorithm: Algorithm,
    },
    OperationFailed {
        operation: &'static str,
        code: i32,
    },
    NullHandle {
        operation: &'static str,
    },
    Closed {
        resource: &'static str,
    },
    InvalidFieldKey {
        key: String,
    },
    InvalidHashLength {
        expected: usize,
        actual: usize,
    },
    NulByte {
        argument: &'static str,
    },
    Utf8Error {
        operation: &'static str,
    },
}
Wraps failures returned by Compression and AppleArchive helpers.

Variants



BufferOperationFailed

Wraps the BufferOperationFailed failure case reported by Compression or AppleArchive helpers.

Fields

operation: &'static str

Wraps the failing Compression or AppleArchive entry-point name.

algorithm: Algorithm

Wraps the algorithm associated with the failing Compression call.

input_len: usize

Wraps the input length passed to the failing buffer operation.

output_capacity: usize

Wraps the destination capacity passed to the failing buffer operation.



StreamInitFailed

Wraps the StreamInitFailed failure case reported by Compression or AppleArchive helpers.

Fields

operation: &'static str

Wraps the failing Compression or AppleArchive entry-point name.

algorithm: Algorithm

Wraps the algorithm associated with the failing Compression call.



StreamProcessFailed

Wraps the StreamProcessFailed failure case reported by Compression or AppleArchive helpers.

Fields

operation: &'static str

Wraps the failing Compression or AppleArchive entry-point name.

algorithm: Algorithm

Wraps the algorithm associated with the failing Compression call.

status: i32

Wraps the compression_stream_process status code.



StreamStalled

Wraps the StreamStalled failure case reported by Compression or AppleArchive helpers.

Fields

operation: &'static str

Wraps the failing Compression or AppleArchive entry-point name.

algorithm: Algorithm

Wraps the algorithm associated with the failing Compression call.



StreamFinished

Wraps the StreamFinished failure case reported by Compression or AppleArchive helpers.

Fields

operation: &'static str

Wraps the failing Compression or AppleArchive entry-point name.

algorithm: Algorithm

Wraps the algorithm associated with the failing Compression call.



OperationFailed

Wraps the OperationFailed failure case reported by Compression or AppleArchive helpers.

Fields

operation: &'static str

Wraps the failing Compression or AppleArchive entry-point name.

code: i32

Wraps the failing Compression or AppleArchive status code.



NullHandle

Wraps the NullHandle failure case reported by Compression or AppleArchive helpers.

Fields

operation: &'static str

Wraps the failing Compression or AppleArchive entry-point name.



Closed

Wraps the Closed failure case reported by Compression or AppleArchive helpers.

Fields

resource: &'static str

Wraps the closed resource name reported by AppleArchive helpers.



InvalidFieldKey

Wraps the InvalidFieldKey failure case reported by Compression or AppleArchive helpers.

Fields

key: String

Wraps the invalid AppleArchive field key.



InvalidHashLength

Wraps the InvalidHashLength failure case reported by Compression or AppleArchive helpers.

Fields

expected: usize

Wraps the expected hash length.

actual: usize

Wraps the actual hash length.



NulByte

Wraps the NulByte failure case reported by Compression or AppleArchive helpers.

Fields

argument: &'static str

Wraps the argument name that contained an interior NUL byte.



Utf8Error

Wraps the Utf8Error failure case reported by Compression or AppleArchive helpers.

Fields

operation: &'static str

Wraps the failing Compression or AppleArchive entry-point name.